@@ -30,8 +30,8 @@ class QmlPlugins : public QQmlExtensionPlugin
 Q_OBJECT
 Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    virtual void initializeEngine(QQmlEngine *engine, const char *uri);
-    virtual void registerTypes(const char *uri);
+    void initializeEngine(QQmlEngine *engine, const char *uri) Q_DECL_OVERRIDE;
+    void registerTypes(const char *uri) Q_DECL_OVERRIDE;
 };
 
 #endif // _MILOU_QML_PLUGINS_H
